@@ -603,6 +603,8 @@ def imshow(
     scale: ContinousColorScales = ContinousColorScales.rdbu,
     scale_midpoint: Optional[float] = None,
     value_text: bool = False,
+    x: Optional[np.ndarray] = None,
+    y: Optional[np.ndarray] = None,
 ) -> go.Figure:
     """
     Create an image plot.
@@ -617,6 +619,8 @@ def imshow(
         color_continuous_scale=color_continuous_scale,
         color_continuous_midpoint=scale_midpoint,
         text_auto=value_text,
+        x=x,
+        y=y,
     )
 
 
@@ -698,7 +702,7 @@ def scatter_matrix(
     if dimensions is not None:
         dimensions_list = [s.strip() for s in dimensions.split(",")]
     else:
-        dimensions_list = data.columns
+        dimensions_list = list(data.columns)
 
     if color is not None:
         if color in dimensions_list:
@@ -733,7 +737,7 @@ def parallel_coordinates(
     if dimensions is not None:
         dimensions_list = [s.strip() for s in dimensions.split(",")]
     else:
-        dimensions_list = data.columns
+        dimensions_list = list(data.columns)
 
     color_continuous_scale = ContinousColorScales.v(color_continuous_scale)
 
@@ -768,7 +772,7 @@ def parallel_categories(
     if dimensions is not None:
         dimensions_list = [s.strip() for s in dimensions.split(",")]
     else:
-        dimensions_list = data.columns
+        dimensions_list = list(data.columns)
 
     color_continuous_scale = ContinousColorScales.v(color_continuous_scale)
 
